==> org.eclipse.wb.core.java.source_1.10.100.202311120723.jar: org/eclipse/wb/internal/core/model/description/rules/StandardBeanPropertyTagRule.java <==
/*******************************************************************************
 * Copyright (c) 2011 Google, Inc.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    Google, Inc. - initial API and implementation
 *******************************************************************************/
package org.eclipse.wb.internal.core.model.description.rules;

import org.eclipse.wb.internal.core.model.description.ComponentDescription;
import org.eclipse.wb.internal.core.model.description.GenericPropertyDescription;

import org.apache.commons.digester3.Rule;
import org.xml.sax.Attributes;

/**
 * The {@link Rule} that adds some tag for standard bean property, created by
 * {@link StandardBeanPropertiesRule}.
 *
 * @author scheglov_ke
 * @coverage core.model.description
 */
public final class StandardBeanPropertyTagRule extends AbstractDesignerRule {
	////////////////////////////////////////////////////////////////////////////
	//
	// Rule
	//
	////////////////////////////////////////////////////////////////////////////
	@Override
	public void begin(String namespace, String name, Attributes attributes) throws Exception {
		String propertyName = getRequiredAttribute(name, attributes, "name");
		// check all properties
		ComponentDescription componentDescription = (ComponentDescription) getDigester().peek();
		for (GenericPropertyDescription propertyDescription : componentDescription.getProperties()) {
			String id = propertyDescription.getId();
			if (StandardBeanPropertiesFlaggedRule.matchPropertyId(id, propertyName)) {
				String tag = getRequiredAttribute(name, attributes, "tag");
				String value = getRequiredAttribute(name, attributes, "value");
				propertyDescription.putTag(tag, value);
			}
		}
	}
}

==> org.eclipse.wb.core.java.source_1.12.100.202411152029.jar: org/eclipse/wb/internal/core/model/description/rules/StandardBeanPropertyTagRule.java <==
/*******************************************************************************
 * Copyright (c) 2011, 2024 Google, Inc.
 * All rights reserved. This program and the accompanying materials
 * are made available under the terms of the Eclipse Public License v1.0
 * which accompanies this distribution, and is available at
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Contributors:
 *    Google, Inc. - initial API and implementation
 *******************************************************************************/
package org.eclipse.wb.internal.core.model.description.rules;

import org.eclipse.wb.core.databinding.xsd.component.Component.PropertyTag;
import org.eclipse.wb.internal.core.model.description.ComponentDescription;
import org.eclipse.wb.internal.core.model.description.GenericPropertyDescription;

import org.apache.commons.lang3.function.FailableBiConsumer;

/**
 * The {@link FailableBiConsumer} that adds some tag for standard bean property,
 * created by {@link StandardBeanPropertiesRule}.
 *
 * @author scheglov_ke
 * @coverage core.model.description
 */
public final class StandardBeanPropertyTagRule
		implements FailableBiConsumer<ComponentDescription, PropertyTag, Exception> {
	////////////////////////////////////////////////////////////////////////////
	//
	// Rule
	//
	////////////////////////////////////////////////////////////////////////////
	@Override
	public void accept(ComponentDescription componentDescription, PropertyTag propertyTag) throws Exception {
		String propertyName = propertyTag.getName();
		// check all properties
		for (GenericPropertyDescription propertyDescription : componentDescription.getProperties()) {
			String id = propertyDescription.getId();
			if (StandardBeanPropertiesFlaggedRule.matchPropertyId(id, propertyName)) {
				String tag = propertyTag.getTag();
				String value = propertyTag.getValue();
				propertyDescription.putTag(tag, value);
			}
		}
	}
}
